@@ -11,7 +11,7 @@ from scipy.integrate import solve_ivp
 
 @dataclasses.dataclass
 class Mmg3DofBasicParams:
-    """Dataclass for setting basic parameters of MMG 3ODF.
+    """Dataclass for setting basic parameters of MMG 3DOF.
 
     Attributes:
         L_pp (float):
@@ -20,28 +20,24 @@ class Mmg3DofBasicParams:
             Ship breadth [m]
         d (float):
             Ship draft [m]
-        nabla (float):
-            Displacement volume of ship [m^3]
         x_G (float):
-            Longitudinal coordinate of center of gravity of ship [-]
+            Longitudinal coordinate of center of gravity of ship [m]
         D_p (float):
             Propeller diameter [m]
-        m_ (float):
-            Ship mass (non-dimensionalized) [-]
+        m (float):
+            Ship mass [kg]
         I_zG (float):
-            Moment of inertia of ship around center of gravity [-]
-        Λ (float):
-            Rudder aspect ratio [-]
-        A_R_Ld (float):
-            Profile area of movable part of mariner rudder[-]
+            Moment of inertia of ship around center of gravity
+        A_R (float):
+            Profile area of movable part of mariner rudder [m^2]
         η (float):
             Ratio of propeller diameter to rudder span (=D_p/HR)
-        m_x_ (float):
-            Added masses of x axis direction (non-dimensionalized)
-        m_y_ (float):
-            Added masses of y axis direction (non-dimensionalized)
+        m_x (float):
+            Added masses of x axis direction [kg]
+        m_y (float):
+            Added masses of y axis direction [kg]
         J_z (float):
-            Added moment of inertia (non-dimensionalized)
+            Added moment of inertia
         f_α (float):
             Rudder lift gradient coefficient
         ϵ (float):
@@ -73,16 +69,14 @@ class Mmg3DofBasicParams:
     L_pp: float
     B: float
     d: float
-    nabla: float
     x_G: float
     D_p: float
-    m_: float
+    m: float
     I_zG: float
-    Λ: float
-    A_R_Ld: float
+    A_R: float
     η: float
-    m_x_: float
-    m_y_: float
+    m_x: float
+    m_y: float
     J_z: float
     f_α: float
     ϵ: float
@@ -101,26 +95,26 @@ class Mmg3DofManeuveringParams:
     """Dataclass for setting maneuvering parameters of MMG 3ODF.
 
     Attributes:
-        C_1 (float): One of manuevering parameters of MMG 3DOF
-        C_2 (float): One of manuevering parameters of MMG 3DOF
-        C_3 (float): One of manuevering parameters of MMG 3DOF
-        X_0 (float): One of manuevering parameters of MMG 3DOF
-        X_ββ (float): One of manuevering parameters of MMG 3DOF
-        X_βγ (float): One of manuevering parameters of MMG 3DOF
-        X_γγ (float): One of manuevering parameters of MMG 3DOF
-        X_ββββ (float): One of manuevering parameters of MMG 3DOF
-        Y_β (float): One of manuevering parameters of MMG 3DOF
-        Y_γ (float): One of manuevering parameters of MMG 3DOF
-        Y_βββ (float): One of manuevering parameters of MMG 3DOF
-        Y_ββγ (float): One of manuevering parameters of MMG 3DOF
-        Y_βγγ (float): One of manuevering parameters of MMG 3DOF
-        Y_γγγ (float): One of manuevering parameters of MMG 3DOF
-        N_β (float): One of manuevering parameters of MMG 3DOF
-        N_γ (float): One of manuevering parameters of MMG 3DOF
-        N_βββ (float): One of manuevering parameters of MMG 3DOF
-        N_ββγ (float): One of manuevering parameters of MMG 3DOF
-        N_βγγ (float): One of manuevering parameters of MMG 3DOF
-        N_γγγ (float): One of manuevering parameters of MMG 3DOF
+        k_0 (float): One of manuevering parameters of coefficients representing K_T
+        k_1 (float): One of manuevering parameters of coefficients representing K_T
+        k_2 (float): One of manuevering parameters of coefficients representing K_T
+        R_0_dash (float): One of manuevering parameters of Ship resistance coefficient in straight moving
+        X_vv_dash (float): One of manuevering parameters of MMG 3DOF
+        X_vr_dash (float): One of manuevering parameters of MMG 3DOF
+        X_rr_dash (float): One of manuevering parameters of MMG 3DOF
+        X_vvvv_dash (float): One of manuevering parameters of MMG 3DOF
+        Y_v_dash (float): One of manuevering parameters of MMG 3DOF
+        Y_r_dash (float): One of manuevering parameters of MMG 3DOF
+        Y_vvv_dash (float): One of manuevering parameters of MMG 3DOF
+        Y_vvr_dash (float): One of manuevering parameters of MMG 3DOF
+        Y_vrr_dash (float): One of manuevering parameters of MMG 3DOF
+        Y_rrr_dash (float): One of manuevering parameters of MMG 3DOF
+        N_v_dash (float): One of manuevering parameters of MMG 3DOF
+        N_r_dash (float): One of manuevering parameters of MMG 3DOF
+        N_vvv_dash (float): One of manuevering parameters of MMG 3DOF
+        N_vvr_dash (float): One of manuevering parameters of MMG 3DOF
+        N_vrr_dash (float): One of manuevering parameters of MMG 3DOF
+        N_rrr_dash (float): One of manuevering parameters of MMG 3DOF
 
     Note:
         For more information, please see the following articles.
@@ -129,34 +123,33 @@ class Mmg3DofManeuveringParams:
           J Mar Sci Technol 20, 37–52 https://doi.org/10.1007/s00773-014-0293-y
     """
 
-    C_1: float
-    C_2: float
-    C_3: float
-    X_0: float
-    X_ββ: float
-    X_βγ: float
-    X_γγ: float
-    X_ββββ: float
-    Y_β: float
-    Y_γ: float
-    Y_βββ: float
-    Y_ββγ: float
-    Y_βγγ: float
-    Y_γγγ: float
-    N_β: float
-    N_γ: float
-    N_βββ: float
-    N_ββγ: float
-    N_βγγ: float
-    N_γγγ: float
+    k_0: float
+    k_1: float
+    k_2: float
+    R_0_dash: float
+    X_vv_dash: float
+    X_vr_dash: float
+    X_rr_dash: float
+    X_vvvv_dash: float
+    Y_v_dash: float
+    Y_r_dash: float
+    Y_vvv_dash: float
+    Y_vvr_dash: float
+    Y_vrr_dash: float
+    Y_rrr_dash: float
+    N_v_dash: float
+    N_r_dash: float
+    N_vvv_dash: float
+    N_vvr_dash: float
+    N_vrr_dash: float
+    N_rrr_dash: float
 
 
 def simulate_mmg_3dof(
     basic_params: Mmg3DofBasicParams,
     maneuvering_params: Mmg3DofManeuveringParams,
-    R_0_func: interp1d,
     time_list: List[float],
-    delta_list: List[float],
+    δ_list: List[float],
     npm_list: List[float],
     u0: float = 0.0,
     v0: float = 0.0,
@@ -173,22 +166,20 @@ def simulate_mmg_3dof(
 
     .. math::
 
-        m (\dot{u}-vr)&=-m_x\dot{u}+m_yvr+X_H+R_0+X_P+X_R
+        m (\\dot{u}-vr)&=-m_x\\dot{u}+m_yvr+X_H+X_P+X_R
 
-        m (\dot{v}+ur)&=-m_y\dot{v}+m_xur+Y_H+Y_R
+        m (\\dot{v}+ur)&=-m_y\\dot{v}+m_xur+Y_H+Y_R
 
-        I_{zG}\dot{r}&=-J_Z\dot{r}+N_H+N_R
+        I_{zG}\\dot{r}&=-J_Z\\dot{r}+N_H+N_R
 
     Args:
         basic_params (Mmg3DofBasicParams):
             Basic paramters for MMG 3DOF simulation.
         maneuvering_params (Mmg3DofManeuveringParams):
             Maneuvering parameters for MMG 3DOF simulation.
-        R_0_func (scipy.interpolate.interp1d):
-            R_0 function which input value is `u`.
         time_list (list[float]):
             time list of simulation.
-        delta_list (list[float]):
+        δ_list (list[float]):
             rudder angle list of simulation.
         npm_list (List[float]):
             npm list of simulation.
@@ -297,68 +288,64 @@ def simulate_mmg_3dof(
                 True if the solver reached the interval end or a termination event occurred (`status >= 0`).
 
     Examples:
-        >>> duration = 50  # [s]
+        >>> duration = 200  # [s]
         >>> sampling = 2000
         >>> time_list = np.linspace(0.00, duration, sampling)
-        >>> delta_list = np.full(len(time_list), 30.0 * np.pi / 180.0)
+        >>> δ_list = np.full(len(time_list), 35.0 * np.pi / 180.0)
         >>> npm_list = np.full(len(time_list), 20.338)
-        >>> R0_func = scipy.interpolate.interp1d(np.linspace(0.0, 10.0, 10), np.full(10, 0.0))
         >>> basic_params = Mmg3DofBasicParams(
-        >>>                     L_pp=2.19048,
-        >>>                     B=0.3067,
-        >>>                     d=0.10286,
-        >>>                     nabla=0.04495,
-        >>>                     x_G=0.0,
-        >>>                     D_p=0.0756,
-        >>>                     m_=0.1822,
-        >>>                     I_zG=0.01138,
-        >>>                     Λ=2.1683,
-        >>>                     A_R_Ld=0.01867,
-        >>>                     η=0.7916,
-        >>>                     m_x_=0.00601,
-        >>>                     m_y_=0.1521,
-        >>>                     J_z=0.00729,
-        >>>                     f_α=(6.13 * 2.1683) / (2.25 + 2.1683),
-        >>>                     ϵ=0.90,
-        >>>                     t_R=0.441,
-        >>>                     a_H=0.232,
-        >>>                     x_H=-0.711,
-        >>>                     γ_R=0.4115,
-        >>>                     l_R=-0.774,
-        >>>                     κ=0.713,
-        >>>                     t_P=0.20,
-        >>>                     w_P0=0.326,
+        >>>                     L_pp=7.00,
+        >>>                     B=1.27,
+        >>>                     d=0.46,
+        >>>                     x_G=0.25,
+        >>>                     D_p=0.216,
+        >>>                     m=3.27*1.025,
+        >>>                     I_zG=m*((0.25 * L_pp) ** 2),
+        >>>                     A_R=0.0539,
+        >>>                     η=D_p/0.345,
+        >>>                     m_x=0.022*(0.5 * ρ * (L_pp ** 2) * d),
+        >>>                     m_y=0.223*(0.5 * ρ * (L_pp ** 2) * d),
+        >>>                     J_z=0.011*(0.5 * ρ * (L_pp ** 4) * d),
+        >>>                     f_α=2.747,
+        >>>                     ϵ=1.09,
+        >>>                     t_R=0.387,
+        >>>                     a_H=0.312,
+        >>>                     x_H=-0.464*L_pp,
+        >>>                     γ_R=0.395,
+        >>>                     l_R=-0.710,
+        >>>                     κ=0.50,
+        >>>                     t_P=0.220,
+        >>>                     w_P0=0.40,
         >>>                 )
         >>> maneuvering_params = Mmg3DofManeuveringParams(
-        >>>                    C_1=0.48301,
-        >>>                    C_2=-0.29765,
-        >>>                    C_3=-0.16423,
-        >>>                    X_0=-0.07234,
-        >>>                    X_ββ=-0.23840,
-        >>>                    X_βγ=-0.03231 + 0.1521,
-        >>>                    X_γγ=-0.06405,
-        >>>                    X_ββββ=-0.30047,
-        >>>                    Y_β=0.85475,
-        >>>                    Y_γ=0.11461 + 0.00601,
-        >>>                    Y_βββ=6.73201,
-        >>>                    Y_ββγ=-2.23689,
-        >>>                    Y_βγγ=3.38577,
-        >>>                    Y_γγγ=-0.04151,
-        >>>                    N_β=0.096567,
-        >>>                    N_γ=-0.036501,
-        >>>                    N_βββ=0.14090,
-        >>>                    N_ββγ=-0.46158,
-        >>>                    N_βγγ=0.01648,
-        >>>                    N_γγγ=-0.030404,
+        >>>                     k_0 = 0.2931,
+        >>>                     k_1 = -0.2753,
+        >>>                     k_2 = -0.1385,
+        >>>                     R_0_dash = 0.022,
+        >>>                     X_vv_dash = -0.040,
+        >>>                     X_vr_dash = 0.002,
+        >>>                     X_rr_dash = 0.011,
+        >>>                     X_vvvv_dash = 0.771,
+        >>>                     Y_v_dash = -0.315,
+        >>>                     Y_r_dash = 0.083,
+        >>>                     Y_vvv_dash = -1.607,
+        >>>                     Y_vvr_dash = 0.379,
+        >>>                     Y_vrr_dash = -0.391,
+        >>>                     Y_rrr_dash = 0.008,
+        >>>                     N_v_dash = -0.137,
+        >>>                     N_r_dash = -0.049,
+        >>>                     N_vvv_dash = -0.030,
+        >>>                     N_vvr_dash = -0.294,
+        >>>                     N_vrr_dash = 0.055,
+        >>>                     N_rrr_dash = -0.013,
         >>>                )
         >>> sol = simulate_mmg_3dof(
         >>>                    basic_params,
         >>>                    maneuvering_params,
-        >>>                    R0_func,
         >>>                    time_list,
-        >>>                    delta_rad_list,
+        >>>                    δ_rad_list,
         >>>                    npm_list,
-        >>>                    u0=1.21,
+        >>>                    u0=2.29 * 0.512,
         >>>                )
         >>> result = sol.sol(time_list)
 
@@ -374,16 +361,14 @@ def simulate_mmg_3dof(
         L_pp=basic_params.L_pp,
         B=basic_params.B,
         d=basic_params.d,
-        nabla=basic_params.nabla,
         x_G=basic_params.x_G,
         D_p=basic_params.D_p,
-        m_=basic_params.m_,
+        m=basic_params.m,
         I_zG=basic_params.I_zG,
-        Λ=basic_params.Λ,
-        A_R_Ld=basic_params.A_R_Ld,
+        A_R=basic_params.A_R,
         η=basic_params.η,
-        m_x_=basic_params.m_x_,
-        m_y_=basic_params.m_y_,
+        m_x=basic_params.m_x,
+        m_y=basic_params.m_y,
         J_z=basic_params.J_z,
         f_α=basic_params.f_α,
         ϵ=basic_params.ϵ,
@@ -395,29 +380,28 @@ def simulate_mmg_3dof(
         κ=basic_params.κ,
         t_P=basic_params.t_P,
         w_P0=basic_params.w_P0,
-        C_1=maneuvering_params.C_1,
-        C_2=maneuvering_params.C_2,
-        C_3=maneuvering_params.C_3,
-        X_0=maneuvering_params.X_0,
-        X_ββ=maneuvering_params.X_ββ,
-        X_βγ=maneuvering_params.X_βγ,
-        X_γγ=maneuvering_params.X_γγ,
-        X_ββββ=maneuvering_params.X_ββββ,
-        Y_β=maneuvering_params.Y_β,
-        Y_γ=maneuvering_params.Y_γ,
-        Y_βββ=maneuvering_params.Y_βββ,
-        Y_ββγ=maneuvering_params.Y_ββγ,
-        Y_βγγ=maneuvering_params.Y_βγγ,
-        Y_γγγ=maneuvering_params.Y_γγγ,
-        N_β=maneuvering_params.N_β,
-        N_γ=maneuvering_params.N_γ,
-        N_βββ=maneuvering_params.N_βββ,
-        N_ββγ=maneuvering_params.N_ββγ,
-        N_βγγ=maneuvering_params.N_βγγ,
-        N_γγγ=maneuvering_params.N_γγγ,
-        R_0_func=R_0_func,
+        k_0=maneuvering_params.k_0,
+        k_1=maneuvering_params.k_1,
+        k_2=maneuvering_params.k_2,
+        R_0_dash=maneuvering_params.R_0_dash,
+        X_vv_dash=maneuvering_params.X_vv_dash,
+        X_vr_dash=maneuvering_params.X_vr_dash,
+        X_rr_dash=maneuvering_params.X_rr_dash,
+        X_vvvv_dash=maneuvering_params.X_vvvv_dash,
+        Y_v_dash=maneuvering_params.Y_v_dash,
+        Y_r_dash=maneuvering_params.Y_r_dash,
+        Y_vvv_dash=maneuvering_params.Y_vvv_dash,
+        Y_vvr_dash=maneuvering_params.Y_vvr_dash,
+        Y_vrr_dash=maneuvering_params.Y_vrr_dash,
+        Y_rrr_dash=maneuvering_params.Y_rrr_dash,
+        N_v_dash=maneuvering_params.N_v_dash,
+        N_r_dash=maneuvering_params.N_r_dash,
+        N_vvv_dash=maneuvering_params.N_vvv_dash,
+        N_vvr_dash=maneuvering_params.N_vvr_dash,
+        N_vrr_dash=maneuvering_params.N_vrr_dash,
+        N_rrr_dash=maneuvering_params.N_rrr_dash,
         time_list=time_list,
-        delta_list=delta_list,
+        δ_list=δ_list,
         npm_list=npm_list,
         u0=u0,
         v0=v0,
@@ -435,16 +419,14 @@ def simulate(
     L_pp: float,
     B: float,
     d: float,
-    nabla: float,
     x_G: float,
     D_p: float,
-    m_: float,
+    m: float,
     I_zG: float,
-    Λ: float,
-    A_R_Ld: float,
+    A_R: float,
     η: float,
-    m_x_: float,
-    m_y_: float,
+    m_x: float,
+    m_y: float,
     J_z: float,
     f_α: float,
     ϵ: float,
@@ -456,29 +438,28 @@ def simulate(
     κ: float,
     t_P: float,
     w_P0: float,
-    C_1: float,
-    C_2: float,
-    C_3: float,
-    X_0: float,
-    X_ββ: float,
-    X_βγ: float,
-    X_γγ: float,
-    X_ββββ: float,
-    Y_β: float,
-    Y_γ: float,
-    Y_βββ: float,
-    Y_ββγ: float,
-    Y_βγγ: float,
-    Y_γγγ: float,
-    N_β: float,
-    N_γ: float,
-    N_βββ: float,
-    N_ββγ: float,
-    N_βγγ: float,
-    N_γγγ: float,
-    R_0_func: interp1d,
+    k_0: float,
+    k_1: float,
+    k_2: float,
+    R_0_dash: float,
+    X_vv_dash: float,
+    X_vr_dash: float,
+    X_rr_dash: float,
+    X_vvvv_dash: float,
+    Y_v_dash: float,
+    Y_r_dash: float,
+    Y_vvv_dash: float,
+    Y_vvr_dash: float,
+    Y_vrr_dash: float,
+    Y_rrr_dash: float,
+    N_v_dash: float,
+    N_r_dash: float,
+    N_vvv_dash: float,
+    N_vvr_dash: float,
+    N_vrr_dash: float,
+    N_rrr_dash: float,
     time_list: List[float],
-    delta_list: List[float],
+    δ_list: List[float],
     npm_list: List[float],
     u0: float = 0.0,
     v0: float = 0.0,
@@ -495,11 +476,11 @@ def simulate(
 
     .. math::
 
-        m (\dot{u}-vr)&=-m_x\dot{u}+m_yvr+X_H+R_0+X_P+X_R
+        m (\\dot{u}-vr)&=-m_x\\dot{u}+m_yvr+X_H+X_P+X_R
 
-        m (\dot{v}+ur)&=-m_y\dot{v}+m_xur+Y_H+Y_R
+        m (\\dot{v}+ur)&=-m_y\\dot{v}+m_xur+Y_H+Y_R
 
-        I_{zG}\dot{r}&=-J_Z\dot{r}+N_H+N_R
+        I_{zG}\\dot{r}&=-J_Z\\dot{r}+N_H+N_R
 
     Args:
         L_pp (float):
@@ -508,28 +489,24 @@ def simulate(
             Ship breadth [m]
         d (float):
             Ship draft [m]
-        nabla (float):
-            Displacement volume of ship [m^3]
         x_G (float):
-            Longitudinal coordinate of center of gravity of ship [-]
+            Longitudinal coordinate of center of gravity of ship
         D_p (float):
             Propeller diameter [m]
-        m_ (float):
-            Ship mass (non-dimensionalized) [-]
+        m (float):
+            Ship mass [kg]
         I_zG (float):
-            Moment of inertia of ship around center of gravity [-]
-        Λ (float):
-            Rudder aspect ratio [-]
-        A_R_Ld (float):
-            Profile area of movable part of mariner rudder[-]
+            Moment of inertia of ship around center of gravity
+        A_R (float):
+            Profile area of movable part of mariner rudder [m^2]
         η (float):
             Ratio of propeller diameter to rudder span (=D_p/HR)
-        m_x_ (float):
-            Added masses of x axis direction (non-dimensionalized)
-        m_y_ (float):
-            Added masses of y axis direction (non-dimensionalized)
+        m_x (float):
+            Added masses of x axis direction [kg]
+        m_y (float):
+            Added masses of y axis direction [kg]
         J_z (float):
-            Added moment of inertia (non-dimensionalized)
+            Added moment of inertia
         f_α (float):
             Rudder lift gradient coefficient
         ϵ (float):
@@ -550,51 +527,49 @@ def simulate(
             Thrust deduction factor
         w_P0 (float):
             Wake coefficient at propeller position in straight moving
-        C_1 (float):
+        k_0 (float):
+            One of manuevering parameters of coefficients representing K_T
+        k_1 (float):
+            One of manuevering parameters of coefficients representing K_T
+        k_2 (float):
+            One of manuevering parameters of coefficients representing K_T
+        R_0_dash (float):
             One of manuevering parameters of MMG 3DOF
-        C_2 (float):
+        X_vv_dash (float):
             One of manuevering parameters of MMG 3DOF
-        C_3 (float):
+        X_vr_dash (float):
             One of manuevering parameters of MMG 3DOF
-        X_0 (float):
+        X_rr_dash (float):
             One of manuevering parameters of MMG 3DOF
-        X_ββ (float):
+        X_vvvv_dash (float):
             One of manuevering parameters of MMG 3DOF
-        X_βγ (float):
+        Y_v_dash (float):
             One of manuevering parameters of MMG 3DOF
-        X_γγ (float):
+        Y_r_dash (float):
             One of manuevering parameters of MMG 3DOF
-        X_ββββ (float):
+        Y_vvv_dash (float):
             One of manuevering parameters of MMG 3DOF
-        Y_β (float):
+        Y_vvr_dash (float):
             One of manuevering parameters of MMG 3DOF
-        Y_γ (float):
+        Y_vrr_dash (float):
             One of manuevering parameters of MMG 3DOF
-        Y_βββ (float):
+        Y_rrr_dash (float):
             One of manuevering parameters of MMG 3DOF
-        Y_ββγ (float):
+        N_v_dash (float):
             One of manuevering parameters of MMG 3DOF
-        Y_βγγ (float):
+        N_r_dash (float):
             One of manuevering parameters of MMG 3DOF
-        Y_γγγ (float):
+        N_vvv_dash (float):
             One of manuevering parameters of MMG 3DOF
-        N_β (float):
+        N_vvr_dash (float):
             One of manuevering parameters of MMG 3DOF
-        N_γ (float):
+        N_vrr_dash (float):
             One of manuevering parameters of MMG 3DOF
-        N_βββ (float):
+        N_rrr_dash (float):
             One of manuevering parameters of MMG 3DOF
-        N_ββγ (float):
-            One of manuevering parameters of MMG 3DOF
-        N_βγγ (float):
-            One of manuevering parameters of MMG 3DOF
-        N_γγγ (float):
-            One of manuevering parameters of MMG 3DOF
-        R_0_func (scipy.interpolate.interp1d):
-            R_0 function which input value is `u`.
         time_list (list[float]):
             time list of simulation.
-        delta_list (list[float]):
+        δ_list (list[float]):
             rudder angle list of simulation.
         npm_list (List[float]):
             npm list of simulation.
@@ -703,70 +678,65 @@ def simulate(
                 True if the solver reached the interval end or a termination event occurred (`status >= 0`).
 
     Examples:
-        >>> duration = 50  # [s]
+        >>> duration = 200  # [s]
         >>> sampling = 2000
         >>> time_list = np.linspace(0.00, duration, sampling)
-        >>> delta_list = np.full(len(time_list), 30.0 * np.pi / 180.0)
-        >>> npm_list = np.full(len(time_list), 20.338)
-        >>> R0_func = scipy.interpolate.interp1d(np.linspace(0.0, 10.0, 10), np.full(10, 0.0))
-        >>> L_pp=2.19048
-        >>> B=0.3067
-        >>> d=0.10286
-        >>> nabla=0.04495
-        >>> x_G=0.0
-        >>> D_p=0.0756
-        >>> m_=0.1822
-        >>> I_zG=0.01138
-        >>> Λ=2.1683
-        >>> A_R_Ld=0.01867
-        >>> η=0.7916
-        >>> m_x_=0.00601
-        >>> m_y_=0.1521
-        >>> J_z=0.00729
-        >>> f_α=(6.13 * 2.1683) / (2.25 + 2.1683)
-        >>> ϵ=0.90
-        >>> t_R=0.441
-        >>> a_H=0.232
-        >>> x_H=-0.711
-        >>> γ_R=0.4115
-        >>> l_R=-0.774
-        >>> κ=0.713
-        >>> t_P=0.20
-        >>> w_P0=0.326
-        >>> C_1=0.48301
-        >>> C_2=-0.29765
-        >>> C_3=-0.16423
-        >>> X_0=-0.07234
-        >>> X_ββ=-0.23840
-        >>> X_βγ=-0.03231 + 0.1521
-        >>> X_γγ=-0.06405
-        >>> X_ββββ=-0.30047
-        >>> Y_β=0.85475
-        >>> Y_γ=0.11461 + 0.00601
-        >>> Y_βββ=6.73201
-        >>> Y_ββγ=-2.23689
-        >>> Y_βγγ=3.38577
-        >>> Y_γγγ=-0.04151
-        >>> N_β=0.096567
-        >>> N_γ=-0.036501
-        >>> N_βββ=0.14090
-        >>> N_ββγ=-0.46158
-        >>> N_βγγ=0.01648
-        >>> N_γγγ=-0.030404
+        >>> δ_list = np.full(len(time_list), 35.0 * np.pi / 180.0)
+        >>> npm_list = np.full(len(time_list), 17.95)
+        >>> L_pp=7.00
+        >>> B=1.27
+        >>> d=0.46
+        >>> x_G=0.25
+        >>> D_p=0.216
+        >>> m=3.27*1.025
+        >>> I_zG=m*((0.25 * L_pp) ** 2)
+        >>> A_R=0.0539
+        >>> η=D_p/0.345
+        >>> m_x=0.022*(0.5 * ρ * (L_pp ** 2) * d)
+        >>> m_y=0.223*(0.5 * ρ * (L_pp ** 2) * d)
+        >>> J_z=0.011*(0.5 * ρ * (L_pp ** 4) * d)
+        >>> f_α=2.747
+        >>> ϵ=1.09
+        >>> t_R=0.387
+        >>> a_H=0.312
+        >>> x_H=-0.464*L_pp
+        >>> γ_R=0.395
+        >>> l_R=-0.710
+        >>> κ=0.50
+        >>> t_P=0.220
+        >>> w_P0=0.40
+        >>> k_0 = 0.2931
+        >>> k_1 = -0.2753
+        >>> k_2 = -0.1385
+        >>> R_0_dash = 0.022
+        >>> X_vv_dash = -0.040
+        >>> X_vr_dash = 0.002
+        >>> X_rr_dash = 0.011
+        >>> X_vvvv_dash = 0.771
+        >>> Y_v_dash = -0.315
+        >>> Y_r_dash = 0.083
+        >>> Y_vvv_dash = -1.607
+        >>> Y_vvr_dash = 0.379
+        >>> Y_vrr_dash = -0.391
+        >>> Y_rrr_dash = 0.008
+        >>> N_v_dash = -0.137
+        >>> N_r_dash = -0.049
+        >>> N_vvv_dash = -0.030
+        >>> N_vvr_dash = -0.294
+        >>> N_vrr_dash = 0.055
+        >>> N_rrr_dash = -0.013
         >>> sol = simulate_mmg_3dof(
         >>>                    L_pp=L_pp,
         >>>                    B=B,
         >>>                    d=d,
-        >>>                    nabla=nabla,
         >>>                    x_G=x_G,
         >>>                    D_p=D_p,
-        >>>                    m_=m_,
+        >>>                    m=m,
         >>>                    I_zG=I_zG,
-        >>>                    Λ=Λ,
-        >>>                    A_R_Ld=A_R_Ld,
+        >>>                    A_R=A_R,
         >>>                    η=η,
-        >>>                    m_x_=m_x_,
-        >>>                    m_y_=m_y_,
+        >>>                    m_x=m_x,
+        >>>                    m_y=m_y,
         >>>                    J_z=J_z,
         >>>                    f_α=f_α,
         >>>                    ϵ=ϵ,
@@ -778,31 +748,30 @@ def simulate(
         >>>                    κ=κ,
         >>>                    t_P=t_P,
         >>>                    w_P0=w_P0,
-        >>>                    C_1=C_1,
-        >>>                    C_2=C_2,
-        >>>                    C_3=C_3,
+        >>>                    k_0=k_0,
+        >>>                    k_1=k_1,
+        >>>                    k_2=k_2,
         >>>                    X_0=X_0,
         >>>                    X_ββ=X_ββ,
         >>>                    X_βγ=X_βγ,
         >>>                    X_γγ=X_γγ,
-        >>>                    X_ββββ=X_ββββ,
+        >>>                    X_vvvv_dash=X_vvvv_dash,
         >>>                    Y_β=Y_β,
         >>>                    Y_γ=Y_γ,
         >>>                    Y_βββ=Y_βββ,
-        >>>                    Y_ββγ=Y_ββγ,
-        >>>                    Y_βγγ=Y_βγγ,
-        >>>                    Y_γγγ=Y_γγγ,
+        >>>                    Y_vvr_dash=Y_vvr_dash,
+        >>>                    Y_vrr_dash=Y_vrr_dash,
+        >>>                    Y_rrr_dash=Y_rrr_dash,
         >>>                    N_β=N_β,
         >>>                    N_γ=N_γ,
-        >>>                    N_βββ=N_βββ,
-        >>>                    N_ββγ=N_ββγ,
-        >>>                    N_βγγ=N_βγγ,
-        >>>                    N_γγγ=N_γγγ,
-        >>>                    R0_func,
+        >>>                    N_vvv_dash=N_vvv_dash,
+        >>>                    N_vvr_dash=N_vvr_dash,
+        >>>                    N_vrr_dash=N_vrr_dash,
+        >>>                    N_rrr_dash=N_rrr_dash,
         >>>                    time_list,
-        >>>                    delta_rad_list,
+        >>>                    δ_rad_list,
         >>>                    npm_list,
-        >>>                    u0=1.21,
+        >>>                    u0=2.29 * 0.512,
         >>>                )
         >>> result = sol.sol(time_list)
 
@@ -813,7 +782,7 @@ def simulate(
           J Mar Sci Technol 20, 37–52 https://doi.org/10.1007/s00773-014-0293-y
 
     """
-    spl_delta = interp1d(time_list, delta_list, "cubic", fill_value="extrapolate")
+    spl_δ = interp1d(time_list, δ_list, "cubic", fill_value="extrapolate")
     spl_npm = interp1d(time_list, npm_list, "cubic", fill_value="extrapolate")
 
     def mmg_3dof_eom_solve_ivp(t, X):
@@ -821,14 +790,16 @@ def simulate(
         u, v, r, δ, npm = X
 
         U = np.sqrt(u ** 2 + (v - r * x_G) ** 2)
-        β = 0.0 if U == 0.0 else np.arcsin(-(v - r * x_G) / U)
 
-        γ_dash = 0.0 if U == 0.0 else r * L_pp / U
+        β = 0.0 if U == 0.0 else np.arcsin(-(v - r * x_G) / U)
+        v_dash = 0.0 if U == 0.0 else v / U
+        r_dash = 0.0 if U == 0.0 else r * L_pp / U
+
         J = 0.0 if npm == 0.0 else (1 - w_P0) * u / (npm * D_p)
-        K_T = C_1 + C_2 * J + C_3 * J ** 2
-        v_R = U * γ_R * (np.sin(β) - l_R * γ_dash)
+        K_T = k_0 + k_1 * J + k_2 * J ** 2
+        v_R = U * γ_R * (β - l_R * r_dash)
         u_R = (
-            np.sqrt(η * (κ * ϵ * 8.0 * C_1 * npm ** 2 * D_p ** 4 / np.pi) ** 2)
+            np.sqrt(η * (κ * ϵ * 8.0 * k_0 * npm ** 2 * D_p ** 4 / np.pi) ** 2)
             if J == 0.0
             else u
             * (1 - w_P0)
@@ -840,7 +811,7 @@ def simulate(
         )
         U_R = np.sqrt(u_R ** 2 + v_R ** 2)
         α_R = δ - np.arctan2(v_R, u_R)
-        F_N = A_R_Ld * f_α * (U_R ** 2) * np.sin(α_R)
+        F_N = 0.5 * A_R * ρ * f_α * (U_R ** 2) * np.sin(α_R)
 
         X_H = (
             0.5
@@ -849,16 +820,15 @@ def simulate(
             * d
             * (U ** 2)
             * (
-                X_0
-                + X_ββ * β ** 2
-                + X_βγ * β * γ_dash
-                + X_γγ * γ_dash ** 2
-                + X_ββββ * β ** 4
+                -R_0_dash
+                + X_vv_dash * (v_dash ** 2)
+                + X_vr_dash * v_dash * r_dash
+                + X_rr_dash * (r_dash ** 2)
+                + X_vvvv_dash * (v_dash ** 4)
             )
         )
-        R_0 = R_0_func(u)
-        X_R = -(1 - t_R) * F_N * np.sin(δ) / L_pp
-        X_P = (1 - t_P) * ρ * K_T * npm ** 2 * D_p ** 4 * (2 / (ρ * d * L_pp ** 2))
+        X_R = -(1 - t_R) * F_N * np.sin(δ)
+        X_P = (1 - t_P) * ρ * K_T * npm ** 2 * D_p ** 4
         Y_H = (
             0.5
             * ρ
@@ -866,15 +836,15 @@ def simulate(
             * d
             * (U ** 2)
             * (
-                Y_β * β
-                + Y_γ * γ_dash
-                + Y_ββγ * (β ** 2) * γ_dash
-                + Y_βγγ * β * (γ_dash ** 2)
-                + Y_βββ * (β ** 3)
-                + Y_γγγ * (γ_dash ** 3)
+                Y_v_dash * v_dash
+                + Y_r_dash * r_dash
+                + Y_vvv_dash * (v_dash ** 3)
+                + Y_vvr_dash * (v_dash ** 2) * r_dash
+                + Y_vrr_dash * v_dash * (r_dash ** 2)
+                + Y_rrr_dash * (r_dash ** 3)
             )
         )
-        Y_R = -(1 + a_H) * F_N * np.cos(δ) / L_pp
+        Y_R = -(1 + a_H) * F_N * np.cos(δ)
         N_H = (
             0.5
             * ρ
@@ -882,26 +852,35 @@ def simulate(
             * d
             * (U ** 2)
             * (
-                N_β * β
-                + N_γ * γ_dash
-                + N_ββγ * (β ** 2) * γ_dash
-                + N_βγγ * β * (γ_dash ** 2)
-                + N_βββ * (β ** 3)
-                + N_γγγ * (γ_dash ** 3)
+                N_v_dash * v_dash
+                + N_r_dash * r_dash
+                + N_vvv_dash * (v_dash ** 3)
+                + N_vvr_dash * (v_dash ** 2) * r_dash
+                + N_vrr_dash * v_dash * (r_dash ** 2)
+                + N_rrr_dash * (r_dash ** 3)
             )
         )
-        N_R = -(-0.5 + a_H * x_H) * F_N * np.cos(δ) / L_pp ** 2
-        d_u = ((X_H - R_0 + X_R + X_P) + (m_ + m_y_) * v * r) / (m_ + m_x_)
-        d_v = ((Y_H + Y_R) - (m_ + m_x_) * u * r) / (m_ + m_y_)
-        d_r = (N_H + N_R) / (I_zG + J_z)
-        d_δ = derivative(spl_delta, t)
+        N_R = -(-0.5 + a_H * x_H) * F_N * np.cos(δ)
+        d_u = ((X_H + X_R + X_P) + (m + m_y) * v * r + x_G * m * (r ** 2)) / (m + m_x)
+        d_v = (
+            (x_G ** 2) * (m ** 2) * u * r
+            - (N_H + N_R) * x_G * m
+            + ((Y_H + Y_R) - (m + m_x) * u * r) * (I_zG + J_z + (x_G ** 2) * m)
+        ) / ((I_zG + J_z + (x_G ** 2) * m) * (m + m_y) - (x_G ** 2) * (m ** 2))
+        d_r = (N_H + N_R - x_G * m * (d_v + u * r)) / (I_zG + J_z + (x_G ** 2) * m)
+        d_δ = derivative(spl_δ, t)
         d_npm = derivative(spl_npm, t)
         return [d_u, d_v, d_r, d_δ, d_npm]
 
     sol = solve_ivp(
         mmg_3dof_eom_solve_ivp,
         [time_list[0], time_list[-1]],
-        [u0, v0, r0, delta_list[0], npm_list[0]],
+        [u0, v0, r0, δ_list[0], npm_list[0]],
         dense_output=True,
+        method=method,
+        t_eval=t_eval,
+        events=events,
+        vectorized=vectorized,
+        **options
     )
     return sol
